@@ -213,6 +213,7 @@ class CdnClient(AbstractClient):
     def CreateVerifyRecord(self, request):
         """CreateVerifyRecord 用于生成一条子域名解析，提示客户添加到域名解析上，用于泛域名及域名取回校验归属权。
         生成的解析记录可通过 [VerifyDomainRecord](https://cloud.tencent.com/document/product/228/48117) 完成归属权校验。
+        注意：生成的解析记录有效期为24小时，超过24小时后，需重新生成。
         具体流程可参考：[使用API接口进行域名归属校验](https://cloud.tencent.com/document/product/228/61702#.E6.96.B9.E6.B3.95.E4.B8.89.EF.BC.9Aapi-.E6.8E.A5.E5.8F.A3.E6.93.8D.E4.BD.9C)
 
         :param request: Request instance for CreateVerifyRecord.
@@ -1901,7 +1902,7 @@ class CdnClient(AbstractClient):
 
     def VerifyDomainRecord(self, request):
         """VerifyDomainRecord 用于验证域名解析值。
-        验证域名解析记录值前，您需要通过 [CreateVerifyRecord](https://cloud.tencent.com/document/product/228/48118) 生成校验解析值。
+        验证域名解析记录值前，您需要通过 [CreateVerifyRecord](https://cloud.tencent.com/document/product/228/48118) 生成校验解析值，验证通过后，24小时有效。
         具体流程可参考：[使用API接口进行域名归属校验](https://cloud.tencent.com/document/product/228/61702#.E6.96.B9.E6.B3.95.E4.B8.89.EF.BC.9Aapi-.E6.8E.A5.E5.8F.A3.E6.93.8D.E4.BD.9C)
 
         :param request: Request instance for VerifyDomainRecord.
