@@ -2051,7 +2051,7 @@ class RedisClient(AbstractClient):
 
 
     def UpgradeInstanceVersion(self, request):
-        """将原本实例升级到高版本实例，或者将主从版实例升级到集群版实例
+        """将当前实例升级到更高版本，或者将当前标准架构升级至集群架构。
 
         :param request: Request instance for UpgradeInstanceVersion.
         :type request: :class:`tencentcloud.redis.v20180412.models.UpgradeInstanceVersionRequest`
